@@ -87,6 +87,9 @@ def get_templates(base_dir):
                     'django.template.loaders.app_directories.Loader',
                 ],
                 'libraries': {
+                    'my': 'webspace.cms.templatetags.my',
+                    'my_minify': 'webspace.cms.templatetags.my_minify',
+                    'my_amp': 'webspace.cms.templatetags.my_amp',
                 }
             },
         },
@@ -130,61 +133,61 @@ RICH_TEXT_FEATURES = [
 ]
 
 LOGGING = {
-        'version': 1,
-        'disable_existing_loggers': False,
-        'formatters': {
-            'verbose': {
-                '()': 'webspace.formatter.DjangoColorsFormatter',
-                'format': '[%(asctime)s] %(levelname)s\033[0m \033[1m%(name)s\033[0m (%(module)s.%(funcName)s.L%(lineno)d) -> %(message)s'
-            },
-            'success': {
-                '()': 'webspace.formatter.DjangoColorsFormatter',
-                'format': '\033[92m[%(asctime)s] SUCCESS\033[0m \033[1m%(name)s\033[0m (%(module)s.%(funcName)s.L%(lineno)d) -> %(message)s'
-            },
-            'simple': {
-                'format': '%(levelname)s %(message)s'
-            },
+    'version': 1,
+    'disable_existing_loggers': False,
+    'formatters': {
+        'verbose': {
+            '()': 'webspace.formatter.DjangoColorsFormatter',
+            'format': '[%(asctime)s] %(levelname)s\033[0m \033[1m%(name)s\033[0m (%(module)s.%(funcName)s.L%(lineno)d) -> %(message)s'
         },
-        'handlers': {
-            'null': {
-                'level': 'DEBUG',
-                'class': 'logging.NullHandler',
-            },
-            'console': {
-                'level': 'DEBUG',
-                'class': 'logging.StreamHandler',
-                'formatter': 'verbose'
-            },
-            'success': {
-                'level': 'DEBUG',
-                'class': 'logging.StreamHandler',
-                'formatter': 'success'
-            },
-            'mail_admins': {
-                'level': 'ERROR',
-                'class': 'django.utils.log.AdminEmailHandler',
-            },
+        'success': {
+            '()': 'webspace.formatter.DjangoColorsFormatter',
+            'format': '\033[92m[%(asctime)s] SUCCESS\033[0m \033[1m%(name)s\033[0m (%(module)s.%(funcName)s.L%(lineno)d) -> %(message)s'
+        },
+        'simple': {
+            'format': '%(levelname)s %(message)s'
+        },
+    },
+    'handlers': {
+        'null': {
+            'level': 'DEBUG',
+            'class': 'logging.NullHandler',
+        },
+        'console': {
+            'level': 'DEBUG',
+            'class': 'logging.StreamHandler',
+            'formatter': 'verbose'
+        },
+        'success': {
+            'level': 'DEBUG',
+            'class': 'logging.StreamHandler',
+            'formatter': 'success'
+        },
+        'mail_admins': {
+            'level': 'ERROR',
+            'class': 'django.utils.log.AdminEmailHandler',
+        },
+    },
+    'loggers': {
+        'django': {
+            'handlers': ['console'],
+            'propagate': True,
+            'level': 'INFO',
+        },
+        'django.db.backends': {
+            'handlers': ['null'],
+            'propagate': False,
+            'level': 'DEBUG',
+        },
+        'aws': {
+            'handlers': ['console'],
+            'propagate': True,
+            'level': 'DEBUG',
+        },
+        'cms': {
+            'handlers': ['success'],
+            'propagate': True,
+            'level': 'DEBUG',
         },
-        'loggers': {
-            'django': {
-                'handlers': ['console'],
-                'propagate': True,
-                'level': 'INFO',
-            },
-            'django.db.backends': {
-                'handlers': ['null'],
-                'propagate': False,
-                'level': 'DEBUG',
-            },
-            'aws': {
-                'handlers': ['console'],
-                'propagate': True,
-                'level': 'DEBUG',
-            },
-            'cms': {
-                'handlers': ['success'],
-                'propagate': True,
-                'level': 'DEBUG',
-            },
-        }
     }
+}
